ibu
===============================
[![Build Status](https://travis-ci.org/ojengwa/ibu.svg?branch=master)](https://travis-ci.org/ojengwa/ibu) [![Coverage Status](https://coveralls.io/repos/github/ojengwa/ibu/badge.svg?branch=master)](https://coveralls.io/github/ojengwa/ibu?branch=master) [![PyPI version](https://badge.fury.io/py/ibu.svg)](https://badge.fury.io/py/ibu) [![Bitdeli Badge](https://d2weczhvl823v0.cloudfront.net/ojengwa/ibu/trend.png)](https://bitdeli.com/free "Bitdeli Badge")

Overview
--------

A database agnotics migration and data export tool. WIP

Installation / Usage
--------------------

To install use pip:

    $ pip install ibu


Or clone the repo:

    $ git clone https://github.com/ojengwa/ibu.git

    $ python setup.py install

Contributing
------------

TBD

Example
-------

TBD


